@@ -80,6 +80,14 @@ module Gitlab
     # like if you have constraints or database-specific column types
     # config.active_record.schema_format = :sql
 
+    # Configure webpack
+    config.webpack.config_file = "config/webpack.config.js"
+    config.webpack.output_dir  = "public/assets/webpack"
+    config.webpack.public_path = "assets/webpack"
+
+    # Webpack dev server configuration is handled in initializers/static_files.rb
+    config.webpack.dev_server.enabled = false
+
     # Enable the asset pipeline
     config.assets.enabled = true
     config.assets.paths << Gemojione.images_path
@@ -88,31 +96,13 @@ module Gitlab
     config.assets.precompile << "print.css"
     config.assets.precompile << "notify.css"
     config.assets.precompile << "mailers/*.css"
-    config.assets.precompile << "lib/vue_resource.js"
     config.assets.precompile << "katex.css"
     config.assets.precompile << "katex.js"
     config.assets.precompile << "xterm/xterm.css"
-    config.assets.precompile << "graphs/graphs_bundle.js"
-    config.assets.precompile << "users/users_bundle.js"
-    config.assets.precompile << "network/network_bundle.js"
-    config.assets.precompile << "profile/profile_bundle.js"
-    config.assets.precompile << "protected_branches/protected_branches_bundle.js"
-    config.assets.precompile << "diff_notes/diff_notes_bundle.js"
-    config.assets.precompile << "merge_request_widget/ci_bundle.js"
-    config.assets.precompile << "issuable/issuable_bundle.js"
-    config.assets.precompile << "boards/boards_bundle.js"
-    config.assets.precompile << "cycle_analytics/cycle_analytics_bundle.js"
-    config.assets.precompile << "merge_conflicts/merge_conflicts_bundle.js"
-    config.assets.precompile << "boards/test_utils/simulate_drag.js"
-    config.assets.precompile << "environments/environments_bundle.js"
-    config.assets.precompile << "blob_edit/blob_edit_bundle.js"
-    config.assets.precompile << "snippet/snippet_bundle.js"
-    config.assets.precompile << "terminal/terminal_bundle.js"
-    config.assets.precompile << "filtered_search/filtered_search_bundle.js"
-    config.assets.precompile << "lib/utils/*.js"
-    config.assets.precompile << "lib/*.js"
+    config.assets.precompile << "lib/ace.js"
+    config.assets.precompile << "lib/cropper.js"
+    config.assets.precompile << "lib/raphael.js"
     config.assets.precompile << "u2f.js"
-    config.assets.precompile << "vue_pipelines_index/index.js"
     config.assets.precompile << "vendor/assets/fonts/*"
 
     # Version of your assets, change this if you want to expire all your assets
