@@ -1,16 +1,13 @@
-/* eslint-disable func-names, space-before-function-paren, wrap-iife, prefer-arrow-callback, padded-blocks, max-len */
-/* global Turbolinks */
+/* eslint-disable func-names, space-before-function-paren, wrap-iife, prefer-arrow-callback, max-len */
 
 (function() {
   this.ProjectImport = (function() {
     function ProjectImport() {
       setTimeout(function() {
-        return Turbolinks.visit(location.href);
+        return gl.utils.visitUrl(location.href);
       }, 5000);
     }
 
     return ProjectImport;
-
   })();
-
 }).call(this);
