@@ -1,7 +1,7 @@
 module BuildsHelper
   def sidebar_build_class(build, current_build)
     build_class = ''
-    build_class += ' active' if build == current_build
+    build_class += ' active' if build.id === current_build.id
     build_class += ' retried' if build.retried?
     build_class
   end
