@@ -30,6 +30,15 @@ module IssuablesHelper
     end
   end
 
+  def serialize_issuable(issuable)
+    case issuable
+    when Issue
+      IssueSerializer.new.represent(issuable).to_json
+    when MergeRequest
+      MergeRequestSerializer.new.represent(issuable).to_json
+    end
+  end
+
   def template_dropdown_tag(issuable, &block)
     title = selected_template(issuable) || "Choose a template"
     options = {
@@ -96,8 +105,8 @@ module IssuablesHelper
 
     if issuable.tasks?
       output << "&ensp;".html_safe
-      output << content_tag(:span, issuable.task_status, id: "task_status", class: "hidden-xs")
-      output << content_tag(:span, issuable.task_status_short, id: "task_status_short", class: "hidden-sm hidden-md hidden-lg")
+      output << content_tag(:span, issuable.task_status, id: "task_status", class: "hidden-xs hidden-sm")
+      output << content_tag(:span, issuable.task_status_short, id: "task_status_short", class: "hidden-md hidden-lg")
     end
 
     output
@@ -153,6 +162,10 @@ module IssuablesHelper
     ]
   end
 
+  def issuable_reference(issuable)
+    @show_full_reference ? issuable.to_reference(full: true) : issuable.to_reference(@group || @project)
+  end
+
   def issuable_filter_present?
     issuable_filter_params.any? { |k| params.key?(k) }
   end
