@@ -15,7 +15,7 @@ module Gitlab
       end
 
       def serialize(event)
-        AnalyticsMergeRequestSerializer.new(project: @project).represent(event).as_json
+        AnalyticsMergeRequestSerializer.new(project: @project).represent(event)
       end
     end
   end
