@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe Admin::GroupsController do
   let(:group) { create(:group) }
-  let(:project) { create(:project, namespace: group) }
+  let(:project) { create(:empty_project, namespace: group) }
   let(:admin) { create(:admin) }
 
   before do
