@@ -1,5 +1,4 @@
 require 'spec_helper'
-require_relative 'import_spec_helper'
 
 describe Import::FogbugzController do
   include ImportSpecHelper
@@ -17,7 +16,7 @@ describe Import::FogbugzController do
     end
 
     it 'assigns variables' do
-      @project = create(:project, import_type: 'fogbugz', creator_id: user.id)
+      @project = create(:empty_project, import_type: 'fogbugz', creator_id: user.id)
       stub_client(repos: [@repo])
 
       get :status
@@ -27,7 +26,7 @@ describe Import::FogbugzController do
     end
 
     it 'does not show already added project' do
-      @project = create(:project, import_type: 'fogbugz', creator_id: user.id, import_source: 'vim')
+      @project = create(:empty_project, import_type: 'fogbugz', creator_id: user.id, import_source: 'vim')
       stub_client(repos: [@repo])
 
       get :status
