@@ -6,12 +6,6 @@ FactoryGirl.define do
     sequence(:position)
   end
 
-  factory :backlog_list, parent: :list do
-    list_type :backlog
-    label nil
-    position nil
-  end
-
   factory :done_list, parent: :list do
     list_type :done
     label nil
