@@ -9,8 +9,8 @@ describe 'Admin Builds' do
     let(:pipeline) { create(:ci_pipeline) }
 
     context 'All tab' do
-      context 'when have builds' do
-        it 'shows all builds' do
+      context 'when have jobs' do
+        it 'shows all jobs' do
           create(:ci_build, pipeline: pipeline, status: :pending)
           create(:ci_build, pipeline: pipeline, status: :running)
           create(:ci_build, pipeline: pipeline, status: :success)
@@ -19,26 +19,26 @@ describe 'Admin Builds' do
           visit admin_builds_path
 
           expect(page).to have_selector('.nav-links li.active', text: 'All')
-          expect(page).to have_selector('.row-content-block', text: 'All builds')
+          expect(page).to have_selector('.row-content-block', text: 'All jobs')
           expect(page.all('.build-link').size).to eq(4)
           expect(page).to have_link 'Cancel all'
         end
       end
 
-      context 'when have no builds' do
+      context 'when have no jobs' do
         it 'shows a message' do
           visit admin_builds_path
 
           expect(page).to have_selector('.nav-links li.active', text: 'All')
-          expect(page).to have_content 'No builds to show'
+          expect(page).to have_content 'No jobs to show'
           expect(page).not_to have_link 'Cancel all'
         end
       end
     end
 
     context 'Pending tab' do
-      context 'when have pending builds' do
-        it 'shows pending builds' do
+      context 'when have pending jobs' do
+        it 'shows pending jobs' do
           build1 = create(:ci_build, pipeline: pipeline, status: :pending)
           build2 = create(:ci_build, pipeline: pipeline, status: :running)
           build3 = create(:ci_build, pipeline: pipeline, status: :success)
@@ -55,22 +55,22 @@ describe 'Admin Builds' do
         end
       end
 
-      context 'when have no builds pending' do
+      context 'when have no jobs pending' do
         it 'shows a message' do
           create(:ci_build, pipeline: pipeline, status: :success)
 
           visit admin_builds_path(scope: :pending)
 
           expect(page).to have_selector('.nav-links li.active', text: 'Pending')
-          expect(page).to have_content 'No builds to show'
+          expect(page).to have_content 'No jobs to show'
           expect(page).not_to have_link 'Cancel all'
         end
       end
     end
 
     context 'Running tab' do
-      context 'when have running builds' do
-        it 'shows running builds' do
+      context 'when have running jobs' do
+        it 'shows running jobs' do
           build1 = create(:ci_build, pipeline: pipeline, status: :running)
           build2 = create(:ci_build, pipeline: pipeline, status: :success)
           build3 = create(:ci_build, pipeline: pipeline, status: :failed)
@@ -87,22 +87,22 @@ describe 'Admin Builds' do
         end
       end
 
-      context 'when have no builds running' do
+      context 'when have no jobs running' do
         it 'shows a message' do
           create(:ci_build, pipeline: pipeline, status: :success)
 
           visit admin_builds_path(scope: :running)
 
           expect(page).to have_selector('.nav-links li.active', text: 'Running')
-          expect(page).to have_content 'No builds to show'
+          expect(page).to have_content 'No jobs to show'
           expect(page).not_to have_link 'Cancel all'
         end
       end
     end
 
     context 'Finished tab' do
-      context 'when have finished builds' do
-        it 'shows finished builds' do
+      context 'when have finished jobs' do
+        it 'shows finished jobs' do
           build1 = create(:ci_build, pipeline: pipeline, status: :pending)
           build2 = create(:ci_build, pipeline: pipeline, status: :running)
           build3 = create(:ci_build, pipeline: pipeline, status: :success)
@@ -117,14 +117,14 @@ describe 'Admin Builds' do
         end
       end
 
-      context 'when have no builds finished' do
+      context 'when have no jobs finished' do
         it 'shows a message' do
           create(:ci_build, pipeline: pipeline, status: :running)
 
           visit admin_builds_path(scope: :finished)
 
           expect(page).to have_selector('.nav-links li.active', text: 'Finished')
-          expect(page).to have_content 'No builds to show'
+          expect(page).to have_content 'No jobs to show'
           expect(page).to have_link 'Cancel all'
         end
       end
