@@ -14,17 +14,17 @@ feature 'Projects > Members > Master adds member with expiration date', feature:
     login_as(master)
   end
 
-  scenario 'expiration date is displayed in the members list' do
+  scenario 'expiration date is displayed in the members list', js: true do
     travel_to Time.zone.parse('2016-08-06 08:00') do
-      visit namespace_project_project_members_path(project.namespace, project)
-
+      visit namespace_project_settings_members_path(project.namespace, project)
       page.within '.users-project-form' do
         select2(new_member.id, from: '#user_ids', multiple: true)
         fill_in 'expires_at', with: '2016-08-10'
-        click_on 'Add to project'
       end
+      find('.users-project-form').click
+      click_on 'Add to project'
 
-      page.within '.project_member:first-child' do
+      page.within "#project_member_#{new_member.project_members.first.id}" do
         expect(page).to have_content('Expires in 4 days')
       end
     end
@@ -35,7 +35,7 @@ feature 'Projects > Members > Master adds member with expiration date', feature:
       project.team.add_users([new_member.id], :developer, expires_at: '2016-09-06')
       visit namespace_project_project_members_path(project.namespace, project)
 
-      page.within '.project_member:first-child' do
+      page.within "#project_member_#{new_member.project_members.first.id}" do
         find('.js-access-expiration-date').set '2016-08-09'
         wait_for_ajax
         expect(page).to have_content('Expires in 3 days')
