@@ -22,7 +22,7 @@ feature 'Projects > Wiki > User updates wiki page', feature: true do
       click_button 'Save changes'
 
       expect(page).to have_content('Home')
-      expect(page).to have_content("last edited by #{user.name}")
+      expect(page).to have_content("Last edited by #{user.name}")
       expect(page).to have_content('My awesome wiki!')
     end
   end
@@ -37,7 +37,7 @@ feature 'Projects > Wiki > User updates wiki page', feature: true do
       click_button 'Save changes'
 
       expect(page).to have_content('Home')
-      expect(page).to have_content("last edited by #{user.name}")
+      expect(page).to have_content("Last edited by #{user.name}")
       expect(page).to have_content('My awesome wiki!')
     end
   end
