@@ -1,12 +1,12 @@
-/* eslint-disable space-before-function-paren, no-var, padded-blocks */
+/* eslint-disable space-before-function-paren, no-var */
 
-/*= require extensions/jquery */
+require('~/extensions/jquery');
 
 (function() {
   describe('jQuery extensions', function() {
     describe('disable', function() {
       beforeEach(function() {
-        return fixture.set('<input type="text" />');
+        return setFixtures('<input type="text" />');
       });
       it('adds the disabled attribute', function() {
         var $input;
@@ -23,7 +23,7 @@
     });
     return describe('enable', function() {
       beforeEach(function() {
-        return fixture.set('<input type="text" disabled="disabled" class="disabled" />');
+        return setFixtures('<input type="text" disabled="disabled" class="disabled" />');
       });
       it('removes the disabled attribute', function() {
         var $input;
@@ -39,5 +39,4 @@
       });
     });
   });
-
 }).call(this);
