@@ -1,9 +1,9 @@
-/* eslint-disable space-before-function-paren, no-var, one-var, one-var-declaration-per-line, object-shorthand, comma-dangle, no-return-assign, new-cap, padded-blocks, max-len */
+/* eslint-disable space-before-function-paren, no-var, one-var, one-var-declaration-per-line, object-shorthand, comma-dangle, no-return-assign, new-cap, max-len */
 /* global Dropzone */
 /* global Mousetrap */
 /* global ZenMode */
 
-/*= require zen_mode */
+require('~/zen_mode');
 
 (function() {
   var enterZen, escapeKeydown, exitZen;
@@ -76,5 +76,4 @@
       keyCode: 27
     }));
   };
-
 }).call(this);
