@@ -13,7 +13,7 @@ describe Banzai::Filter::VideoLinkFilter, lib: true do
     %(<img src="#{path}" />)
   end
 
-  let(:project) { create(:project) }
+  let(:project) { create(:project, :repository) }
 
   context 'when the element src has a video extension' do
     UploaderHelper::VIDEO_EXT.each do |ext|
