@@ -2,8 +2,8 @@ require 'spec_helper'
 
 describe Gitlab::Gfm::ReferenceRewriter do
   let(:text) { 'some text' }
-  let(:old_project) { create(:project, name: 'old') }
-  let(:new_project) { create(:project, name: 'new') }
+  let(:old_project) { create(:empty_project, name: 'old-project') }
+  let(:new_project) { create(:empty_project, name: 'new-project') }
   let(:user) { create(:user) }
 
   before { old_project.team << [user, :reporter] }
@@ -29,7 +29,7 @@ describe Gitlab::Gfm::ReferenceRewriter do
       context 'description with ignored elements' do
         let(:text) do
           "Hi. This references #1, but not `#2`\n" +
-          '<pre>and not !1</pre>'
+            '<pre>and not !1</pre>'
         end
 
         it { is_expected.to include issue_first.to_reference(new_project) }
