@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'CycleAnalytics#production', feature: true do
   extend CycleAnalyticsHelpers::TestGeneration
 
-  let(:project) { create(:project) }
+  let(:project) { create(:project, :repository) }
   let(:from_date) { 10.days.ago }
   let(:user) { create(:user, :admin) }
   subject { CycleAnalytics.new(project, from: from_date) }
@@ -21,7 +21,13 @@ describe 'CycleAnalytics#production', feature: true do
        ["production deploy happens after merge request is merged (along with other changes)",
         lambda do |context, data|
           # Make other changes on master
-          sha = context.project.repository.commit_file(context.user, context.random_git_name, "content", "commit message", 'master', false)
+          sha = context.project.repository.commit_file(
+            context.user,
+            context.random_git_name,
+            'content',
+            message: 'commit message',
+            branch_name: 'master',
+            update: false)
           context.project.repository.commit(sha)
 
           context.deploy_master
@@ -29,11 +35,9 @@ describe 'CycleAnalytics#production', feature: true do
 
   context "when a regular merge request (that doesn't close the issue) is merged and deployed" do
     it "returns nil" do
-      5.times do
-        merge_request = create(:merge_request)
-        MergeRequests::MergeService.new(project, user).execute(merge_request)
-        deploy_master
-      end
+      merge_request = create(:merge_request)
+      MergeRequests::MergeService.new(project, user).execute(merge_request)
+      deploy_master
 
       expect(subject[:production].median).to be_nil
     end
@@ -41,12 +45,10 @@ describe 'CycleAnalytics#production', feature: true do
 
   context "when the deployment happens to a non-production environment" do
     it "returns nil" do
-      5.times do
-        issue = create(:issue, project: project)
-        merge_request = create_merge_request_closing_issue(issue)
-        MergeRequests::MergeService.new(project, user).execute(merge_request)
-        deploy_master(environment: 'staging')
-      end
+      issue = create(:issue, project: project)
+      merge_request = create_merge_request_closing_issue(issue)
+      MergeRequests::MergeService.new(project, user).execute(merge_request)
+      deploy_master(environment: 'staging')
 
       expect(subject[:production].median).to be_nil
     end
