@@ -8,21 +8,21 @@ describe GitlabIssueTrackerService, models: true do
 
   describe 'Validations' do
     context 'when service is active' do
-      subject { described_class.new(project: create(:project), active: true) }
+      subject { described_class.new(project: create(:empty_project), active: true) }
 
       it { is_expected.to validate_presence_of(:issues_url) }
       it_behaves_like 'issue tracker service URL attribute', :issues_url
     end
 
     context 'when service is inactive' do
-      subject { described_class.new(project: create(:project), active: false) }
+      subject { described_class.new(project: create(:empty_project), active: false) }
 
       it { is_expected.not_to validate_presence_of(:issues_url) }
     end
   end
 
   describe 'project and issue urls' do
-    let(:project) { create(:project) }
+    let(:project) { create(:empty_project) }
 
     context 'with absolute urls' do
       before do
