@@ -7,7 +7,7 @@ describe PipelinesEmailService do
     create(:ci_pipeline, project: project, sha: project.commit('master').sha)
   end
 
-  let(:project) { create(:project) }
+  let(:project) { create(:project, :repository) }
   let(:recipient) { 'test@gitlab.com' }
 
   let(:data) do
