@@ -1,13 +1,13 @@
 require 'spec_helper'
 
 describe AnalyticsStageSerializer do
-  let(:serializer) do
-    described_class
-      .new.represent(resource)
+  subject do
+    described_class.new.represent(resource)
   end
 
-  let(:json) { serializer.as_json }
-  let(:resource) { Gitlab::CycleAnalytics::CodeStage.new(project: double, options: {}) }
+  let(:resource) do
+    Gitlab::CycleAnalytics::CodeStage.new(project: double, options: {})
+  end
 
   before do
     allow_any_instance_of(Gitlab::CycleAnalytics::BaseStage).to receive(:median).and_return(1.12)
@@ -15,10 +15,10 @@ describe AnalyticsStageSerializer do
   end
 
   it 'it generates payload for single object' do
-    expect(json).to be_kind_of Hash
+    expect(subject).to be_kind_of Hash
   end
 
   it 'contains important elements of AnalyticsStage' do
-    expect(json).to include(:title, :description, :value)
+    expect(subject).to include(:title, :description, :value)
   end
 end
