@@ -89,7 +89,7 @@ describe MergeRequests::RefreshService, services: true do
         # Merge master -> feature branch
         author = { email: 'test@gitlab.com', time: Time.now, name: "Me" }
         commit_options = { message: 'Test message', committer: author, author: author }
-        @project.repository.merge(@user, @merge_request, commit_options)
+        @project.repository.merge(@user, @merge_request.diff_head_sha, @merge_request, commit_options)
         commit = @project.repository.commit('feature')
         service.new(@project, @user).execute(@oldrev, commit.id, 'refs/heads/feature')
         reload_mrs
@@ -106,23 +106,46 @@ describe MergeRequests::RefreshService, services: true do
 
     context 'push to fork repo source branch' do
       let(:refresh_service) { service.new(@fork_project, @user) }
-      before do
-        allow(refresh_service).to receive(:execute_hooks)
-        refresh_service.execute(@oldrev, @newrev, 'refs/heads/master')
-        reload_mrs
+
+      context 'open fork merge request' do
+        before do
+          allow(refresh_service).to receive(:execute_hooks)
+          refresh_service.execute(@oldrev, @newrev, 'refs/heads/master')
+          reload_mrs
+        end
+
+        it 'executes hooks with update action' do
+          expect(refresh_service).to have_received(:execute_hooks).
+            with(@fork_merge_request, 'update', @oldrev)
+        end
+
+        it { expect(@merge_request.notes).to be_empty }
+        it { expect(@merge_request).to be_open }
+        it { expect(@fork_merge_request.notes.last.note).to include('added 28 commits') }
+        it { expect(@fork_merge_request).to be_open }
+        it { expect(@build_failed_todo).to be_pending }
+        it { expect(@fork_build_failed_todo).to be_pending }
       end
 
-      it 'executes hooks with update action' do
-        expect(refresh_service).to have_received(:execute_hooks).
-          with(@fork_merge_request, 'update', @oldrev)
-      end
+      context 'closed fork merge request' do
+        before do
+          @fork_merge_request.close!
+          allow(refresh_service).to receive(:execute_hooks)
+          refresh_service.execute(@oldrev, @newrev, 'refs/heads/master')
+          reload_mrs
+        end
 
-      it { expect(@merge_request.notes).to be_empty }
-      it { expect(@merge_request).to be_open }
-      it { expect(@fork_merge_request.notes.last.note).to include('added 28 commits') }
-      it { expect(@fork_merge_request).to be_open }
-      it { expect(@build_failed_todo).to be_pending }
-      it { expect(@fork_build_failed_todo).to be_pending }
+        it 'do not execute hooks with update action' do
+          expect(refresh_service).not_to have_received(:execute_hooks)
+        end
+
+        it { expect(@merge_request.notes).to be_empty }
+        it { expect(@merge_request).to be_open }
+        it { expect(@fork_merge_request.notes).to be_empty }
+        it { expect(@fork_merge_request).to be_closed }
+        it { expect(@build_failed_todo).to be_pending }
+        it { expect(@fork_build_failed_todo).to be_pending }
+      end
     end
 
     context 'push to fork repo target branch' do
@@ -237,6 +260,93 @@ describe MergeRequests::RefreshService, services: true do
       end
     end
 
+    context 'marking the merge request as work in progress' do
+      let(:refresh_service) { service.new(@project, @user) }
+      before do
+        allow(refresh_service).to receive(:execute_hooks)
+      end
+
+      it 'marks the merge request as work in progress from fixup commits' do
+        fixup_merge_request = create(:merge_request,
+                                     source_project: @project,
+                                     source_branch: 'wip',
+                                     target_branch: 'master',
+                                     target_project: @project)
+        commits = fixup_merge_request.commits
+        oldrev = commits.last.id
+        newrev = commits.first.id
+
+        refresh_service.execute(oldrev, newrev, 'refs/heads/wip')
+        fixup_merge_request.reload
+
+        expect(fixup_merge_request.work_in_progress?).to eq(true)
+        expect(fixup_merge_request.notes.last.note).to match(
+          /marked as a \*\*Work In Progress\*\* from #{Commit.reference_pattern}/
+        )
+      end
+
+      it 'references the commit that caused the Work in Progress status' do
+        refresh_service.execute(@oldrev, @newrev, 'refs/heads/master')
+        allow(refresh_service).to receive(:find_new_commits)
+        refresh_service.instance_variable_set("@commits", [
+          double(
+            id: 'aaaaaaa',
+            sha: '38008cb17ce1466d8fec2dfa6f6ab8dcfe5cf49e',
+            short_id: 'aaaaaaa',
+            title: 'Fix issue',
+            work_in_progress?: false
+          ),
+          double(
+            id: 'bbbbbbb',
+            sha: '498214de67004b1da3d820901307bed2a68a8ef6',
+            short_id: 'bbbbbbb',
+            title: 'fixup! Fix issue',
+            work_in_progress?: true,
+            to_reference: 'bbbbbbb'
+          ),
+          double(
+            id: 'ccccccc',
+            sha: '1b12f15a11fc6e62177bef08f47bc7b5ce50b141',
+            short_id: 'ccccccc',
+            title: 'fixup! Fix issue',
+            work_in_progress?: true,
+            to_reference: 'ccccccc'
+          ),
+        ])
+        refresh_service.execute(@oldrev, @newrev, 'refs/heads/wip')
+        reload_mrs
+        expect(@merge_request.notes.last.note).to eq(
+          "marked as a **Work In Progress** from bbbbbbb"
+        )
+      end
+
+      it 'does not mark as WIP based on commits that do not belong to an MR' do
+        allow(refresh_service).to receive(:find_new_commits)
+        refresh_service.instance_variable_set("@commits", [
+          double(
+            id: 'aaaaaaa',
+            sha: 'aaaaaaa',
+            short_id: 'aaaaaaa',
+            title: 'Fix issue',
+            work_in_progress?: false
+          ),
+          double(
+            id: 'bbbbbbb',
+            sha: 'bbbbbbbb',
+            short_id: 'bbbbbbb',
+            title: 'fixup! Fix issue',
+            work_in_progress?: true,
+            to_reference: 'bbbbbbb'
+          )
+        ])
+
+        refresh_service.execute(@oldrev, @newrev, 'refs/heads/master')
+        reload_mrs
+
+        expect(@merge_request.work_in_progress?).to be_falsey
+      end
+    end
+
     def reload_mrs
       @merge_request.reload
       @fork_merge_request.reload
