@@ -653,5 +653,37 @@ describe SlashCommands::InterpretService, services: true do
         let(:issuable) { issue }
       end
     end
+
+    context '/target_branch command' do
+      let(:non_empty_project) { create(:project) }
+      let(:another_merge_request) { create(:merge_request, author: developer, source_project: non_empty_project) }
+      let(:service) { described_class.new(non_empty_project, developer)}
+
+      it 'updates target_branch if /target_branch command is executed' do
+        _, updates = service.execute('/target_branch merge-test', merge_request)
+
+        expect(updates).to eq(target_branch: 'merge-test')
+      end
+
+      it 'handles blanks around param' do
+        _, updates = service.execute('/target_branch  merge-test     ', merge_request)
+
+        expect(updates).to eq(target_branch: 'merge-test')
+      end
+
+      context 'ignores command with no argument' do
+        it_behaves_like 'empty command' do
+          let(:content) { '/target_branch' }
+          let(:issuable) { another_merge_request }
+        end
+      end
+
+      context 'ignores non-existing target branch' do
+        it_behaves_like 'empty command' do
+          let(:content) { '/target_branch totally_non_existing_branch' }
+          let(:issuable) { another_merge_request }
+        end
+      end
+    end
   end
 end
