@@ -8,14 +8,14 @@ describe ProjectDestroyWorker do
 
   describe "#perform" do
     it "deletes the project" do
-      subject.perform(project.id, project.owner, {})
+      subject.perform(project.id, project.owner.id, {})
 
       expect(Project.all).not_to include(project)
       expect(Dir.exist?(path)).to be_falsey
     end
 
     it "deletes the project but skips repo deletion" do
-      subject.perform(project.id, project.owner, { "skip_repo" => true })
+      subject.perform(project.id, project.owner.id, { "skip_repo" => true })
 
       expect(Project.all).not_to include(project)
       expect(Dir.exist?(path)).to be_truthy
